@@ -1,4 +1,4 @@
-from typing import Any, Dict, Tuple, Union, TypeVar, Optional
+from typing import Any, Dict, Tuple, Union, Literal, TypeVar, Optional, NamedTuple
 
 _Number = Union[int, float]
 _Timeout = Optional[Union[_Number, Tuple[_Number, _Number]]]
@@ -17,6 +17,15 @@ class Container:
         return self.fields.get(key, default)
 
 
+class File(NamedTuple):
+    name: str  # file name
+    size: int  # file size in bytes
+    completed: int  # bytes completed
+    priority: Literal["high", "normal", "low"]
+    selected: bool  # if selected for download
+    id: int  # id of the file of this torrent, not should not be used outside the torrent scope.
+
+
 class Group(Container):
     @property
     def name(self) -> str:
